#
# spec file for package krename
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           krename
Version:        4.0.9
Release:        3.2
Summary:        A Powerful Batch Renamer for KDE
License:        GPL-2.0+
Group:          Productivity/File utilities
Url:            http://www.krename.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM desktop-files.diff asterios.dramis@gmail.com -- Make the desktop file KDE and XDG compatible
Patch0:         desktop-files.diff
# PATCH-FIX-UPSTREAM servicemenus-files.patch asterios.dramis@gmail.com -- Make the desktop files KDE and XDG compatible
Patch1:         servicemenus-files.patch
# PATCH-FIX-UPSTREAM krename-4.0.7_add_common_names_to_FindLIBPODOFO.patch sf#3256922 asterios.dramis@gmail.com -- Fix podofo library names cmake check (patch taken from upstream)
Patch2:         krename-4.0.7_add_common_names_to_FindLIBPODOFO.patch
# PATCH-FIX-UPSTREAM remove-gplv2-code.diff dmueller@suse.de -- Remove GPLv2 only code (only used for self-testing)
Patch3:         remove-gplv2-code.diff
# PATCH-FIX-openSUSE tittiatcokeægmail.com -- make sure that the freetype includes are found
Patch4:         fix-freetype2-includes.patch
BuildRequires:  freetype2-devel
BuildRequires:  libexiv2-devel
BuildRequires:  libkde4-devel
BuildRequires:  libpodofo-devel
%if %suse_version > 1200
BuildRequires:  pkgconfig(taglib)
%else
BuildRequires:  taglib-devel
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%kde4_runtime_requires

%description
KRename is a powerful batch renamer for KDE. It allows you to easily rename
hundreds or even more files in one go. The filenames can be created by parts of
the original filename, numbering the files or accessing hundreds of informations
about the file, like creation date or Exif informations of an image.

%prep
%setup -q
%patch0
%patch1
%patch2 -p1
# GPLv2 only code, not really needed, lets avoid the license discussion
rm -rf src/modeltest.*
%patch3
%if 0%{?suse_version} > 1310
%patch4 -p1
%endif

# Remove build time references so build-compare can do its work (fix rpmlint warning "file-contains-date-and-time")
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/main.cpp
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/main.cpp

%build

export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -I%_includedir/freetype2"

%cmake_kde4 -d build 
%make_jobs

%install
cd build
%kde4_makeinstall
cd ..

%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} Qt KDE System FileManager
%endif

%kde_post_install

%find_lang %{name}

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING README TODO
%{_kde4_bindir}/krename
%{_kde4_applicationsdir}/krename.desktop
%{_kde4_iconsdir}/hicolor/*/*/krename.png
%{_kde4_iconsdir}/locolor/*/*/krename.png
%{_kde4_servicesdir}/ServiceMenus/krename_all_nonrec.desktop
%{_kde4_servicesdir}/ServiceMenus/krename_dir_rec.desktop

%changelog
* Sun Mar  9 2014 tittiatcoke@gmail.com
- Add patch fix-freetype2-includes.patch to ensure that the right
  freetype2 includes are found
* Sat Nov 24 2012 alinm.elena@gmail.com
- added freetype2 dependency
* Mon May  7 2012 idonmez@suse.com
- Fix taglib requires for older distros
* Sun Apr 15 2012 dmueller@suse.com
- fix buildrequires (taglib->libtag)
* Wed Jan  4 2012 asterios.dramis@gmail.com
- Update to 4.0.9:
  * Fix for a compilation error in the PoDoFo plugin and updates the Czech
    translation.
  From 4.0.8:
  * Fix a crash on Ubuntu when starting KRename.
- Removed the patch to fix crash on static initialization (fixed upstream).
* Tue Aug 23 2011 dmueller@suse.de
- remove GPLv2 only code (only used for self-testing)
* Sat Aug 13 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed Group: to Productivity/File utilities.
  * Updates in Summary: and %%description sections.
  * Added update-desktop-files in Buildrequires:.
  * Removed support for openSUSE < 11.3.
  * Removed kde4-krename Provides/Obsoletes entries (not needed anymore).
  * Fixed rpmlint warning "file-contains-date-and-time".
  * Minor other updates.
- Modified the patch for krename.desktop to make the desktop file KDE and XDG
  compatible.
- Added a patch for the servicemenus to make them KDE and XDG compatible.
- Added a patch (taken from Fedora) to fix crash on static initialization.
- Added a patch (taken from upstream) to fix podofo library names cmake check.
* Mon Feb 21 2011 toddrme2178@gmail.com
- update to 4.0.7
  * Improved handling of directories
* Tue Feb  1 2011 toddrme2178@gmail.com
- update to 4.0.6
  * Translation updates
  * adds a list of recently-used tokens
* Tue Oct 19 2010 toddrme2178@gmail.com
- update to 4.0.5
  * adds advanced sorting modes
- add optional build-time dependency
  * libpodofo: provides pdf parsing capabilities
* Thu Jul  8 2010 beineri@opensuse.org
- update to 4.0.4
  * Translation updates
  * Some bugfixes
* Mon Feb  8 2010 coolo@novell.com
- update to 4.0.3
  * Translation updates
  * Some bugfixes
* Sun Dec  6 2009 tittiatcoke@gmail.com
- update to 4.0.2
  * Many bugfixes
* Sun Oct 11 2009 beineri@opensuse.org
- update to 4.0.1:
  * updates the German, Hungarian and Italian translation
  * the history of templates is now saved
* Thu Sep 24 2009 beineri@opensuse.org
- update to 4.0: first stable KDE4 release, updated translations
* Tue Jun  2 2009 beineri@opensuse.org
- reviewed changes
* Mon Jun  1 2009 tittiatcoke@gmail.com
- update to 3.9.3
  * countless bug fixes and fixes several crashes.
  * Contains most important features from the KDE3 version.
  * A new setting was introduced, so that KRename will ignore the file extension.
* Thu Oct  9 2008 dmueller@suse.de
- update to 3.9.2 (bnc#432364):
  * readds back missing desktop file and application icon
  * includes translations
* Mon Jul  7 2008 dmueller@suse.de
- update to 3.9.1:
  * 2nd beta release of the KDE4 based rewrite
* Mon Mar 26 2007 stbinner@suse.de
- update to 3.0.14:
  * Fixed a crash with plugin previews
  * Fixed adding directories recursive when dropped from another application
  * Added a unit test
  * Fixed plugin tokens with additional arguments e.g. [date;dd-mm-yyyy]
  * Fixed the seconds in the time [token]
  * Corrected documentation of [user] and [group] tokens
  * Patch by Otakar Trunecek to add Czech transliteration characters
* Mon Dec  4 2006 stbinner@suse.de
- update to 3.0.13:
  * new Turkish translation
  * the encoding plugin is now finally working
  * the speed with plugins could be improved
  * commandline option to specify the number of preview items to show
* Tue Aug 15 2006 dmueller@suse.de
- update to 3.0.12:
  * Updated translation
  * Fixed servicemenu installation
  * Fixed a possible crash
  * Fixed drag and drop of files to KRename
* Wed May 24 2006 adrian@suse.de
- fix build for < 10.1
* Thu Feb 23 2006 stbinner@suse.de
- update to 3.0.11
  * cleans up all makefiles and desktop files
  * updates the build system to the build system of KDE 3.5
  * updates some translations (Swedish and Italian)
  * fixes a bug when *,{ or } was returned by plugins
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 dmueller@suse.de
- spec file cleanup
* Wed Jan 11 2006 stbinner@suse.de
- update to 3.0.10
* Tue Oct 18 2005 stbinner@suse.de
- update to 3.0.9
* Sun Sep 25 2005 stbinner@suse.de
- update to 3.0.8
* Mon Sep 19 2005 stbinner@suse.de
- update to 3.0.7
* Tue Jun 21 2005 dmueller@suse.de
- update to 3.0.6
* Thu Feb 17 2005 adrian@suse.de
- update to version 3.0.3
- menu entry moved to xdg dir
* Thu Oct 14 2004 coolo@suse.de
- update to version 3.0.2
* Mon Feb  2 2004 adrian@suse.de
- update to version 2.8.5
* Wed Jan 14 2004 coolo@suse.de
- fixing build
* Wed Jan 14 2004 coolo@suse.de
- fixing Makefile problems
* Fri Dec  5 2003 adrian@suse.de
- update to version 2.8.4
* Tue Oct 28 2003 adrian@suse.de
- update to version 2.8.3
* Tue Sep  9 2003 adrian@suse.de
- add hungarian translations from Peter Varkoly
* Fri Aug  8 2003 adrian@suse.de
- update to version 2.8.2
* Sun Jul 27 2003 adrian@suse.de
- update to version 2.8.1
- add Categories
* Sat Jun 14 2003 coolo@suse.de
- use %%find_lang
* Sun May 18 2003 adrian@suse.de
- update to version 2.7.1
* Wed May 14 2003 adrian@suse.de
- initial package of version 2.6.2
